@@ -25,7 +25,7 @@ describe 'ceilometer::policy' do
 
   context 'on Debian platforms' do
     let :facts do
-      { :osfamily => 'Debian' }
+      @default_facts.merge({ :osfamily => 'Debian' })
     end
 
     it_configures 'ceilometer policies'
@@ -33,7 +33,7 @@ describe 'ceilometer::policy' do
 
   context 'on RedHat platforms' do
     let :facts do
-      { :osfamily => 'RedHat' }
+      @default_facts.merge({ :osfamily => 'RedHat' })
     end
 
     it_configures 'ceilometer policies'
